--[[

ARLOptions.lua

Blizz UI Options for all of AckisRecipeList

]]--

ARL = AckisRecipeList
local L			= AceLibrary("AceLocale-2.2"):new("AckisRecipeList")

function Sorting_DownMenuItem_OnClick()

	UIDropDownMenu_SetSelectedValue(this.owner, this.value)

end

local function Sorting_DropDown_Initialize()

	-- Set drop down options
	level = level or 1
	local info = UIDropDownMenu_CreateInfo();

	info.text = L["SORT_Name"]
	info.value = 0
	info.func = Sorting_DownMenuItem_OnClick
	info.owner = this:GetParent()
	if (AckisRecipeList.db.profile.sorting == "Name") then

		info.checked = 1
	
	else

		info.checked = nil

	end
	UIDropDownMenu_AddButton(info, level)

	info.text = L["SORT_Skill"]
	info.value = 1
	info.func = Sorting_DownMenuItem_OnClick
	info.owner = this:GetParent()
	if (AckisRecipeList.db.profile.sorting == "Skill") then

		info.checked = 1
	
	else

		info.checked = nil

	end

end

function ARL:CreateGUIOptions()

	-- Create main frame for all the options
	local ARLOptions = CreateFrame("FRAME", "ARLOptions")
	ARLOptions.name = ARL.ARLTitle
	InterfaceOptions_AddCategory(ARLOptions)

	local ARLOptionsText1 = ARLOptions:CreateFontString(nil, "ARTWORK")
	ARLOptionsText1:SetFontObject(GameFontNormalLarge)
	ARLOptionsText1:SetJustifyH("LEFT") 
	ARLOptionsText1:SetJustifyV("TOP")
	ARLOptionsText1:ClearAllPoints()
	ARLOptionsText1:SetPoint("TOPLEFT", 16, -16)
	ARLOptionsText1:SetText(ARL.ARLTitle)

	local ARLOptionsText2 = ARLOptions:CreateFontString(nil, "ARTWORK")
	ARLOptionsText2:SetFontObject(GameFontNormalSmall)
	ARLOptionsText2:SetJustifyH("LEFT") 
	ARLOptionsText2:SetJustifyV("TOP")
	ARLOptionsText2:SetTextColor(1, 1, 1)
	ARLOptionsText2:ClearAllPoints()
	ARLOptionsText2:SetPoint("TOPLEFT", ARLOptionsText1, "BOTTOMLEFT", 16, -16)
	ARLOptionsText2:SetWidth(320)
	ARLOptionsText2:SetText(GetAddOnMetadata("AckisRecipeList", "Notes"))

	-- Filtering Options frame
	local ARLOptionsFilter = CreateFrame("FRAME", "ARLOptionsFilter")
	ARLOptionsFilter.name = L["FILTER_OPTIONS"]
	ARLOptionsFilter.parent = ARL.ARLTitle
	InterfaceOptions_AddCategory(ARLOptionsFilter)

	local ARLOptionsFilterText1 = ARLOptionsFilter:CreateFontString(nil, "ARTWORK")
	ARLOptionsFilterText1:SetFontObject(GameFontNormalLarge)
	ARLOptionsFilterText1:SetJustifyH("LEFT") 
	ARLOptionsFilterText1:SetJustifyV("TOP")
	ARLOptionsFilterText1:SetPoint("TOPLEFT", 16, -16)
	ARLOptionsFilterText1:SetWidth(320)
	ARLOptionsFilterText1:SetText(L["FILTER_OPTIONS"])

	-- Class Toggle
	local ARLOptionsFilterCheck1 = CreateFrame("CheckButton", "ARLOptionsFilterCheck1", ARLOptionsFilter, "UICheckButtonTemplate")
	ARLOptionsFilterCheck1:ClearAllPoints()
	ARLOptionsFilterCheck1:SetPoint("TOPLEFT", 16, -50)

	if (AckisRecipeList.db.profile.classes) then

		ARLOptionsFilterCheck1:SetChecked(true)

	end

	ARLOptionsFilterCheck1.Text = ARLOptionsFilterCheck1:CreateFontString("ARLOptionsFilterCheck1Text", "DIALOG")
	ARLOptionsFilterCheck1.Text:SetFontObject("GameFontNormal")
	ARLOptionsFilterCheck1.Text:SetTextColor(1, 1, 1)
	ARLOptionsFilterCheck1.Text:SetWidth(320)
	ARLOptionsFilterCheck1.Text:SetText(L["CLASS_TOGGLE"])
	ARLOptionsFilterCheck1.Text:SetJustifyH("LEFT")
	ARLOptionsFilterCheck1.Text:ClearAllPoints()
	ARLOptionsFilterCheck1.Text:SetPoint("LEFT", ARLOptionsFilterCheck1, "RIGHT", 0, 0)

	-- PVP Toggle
	local ARLOptionsFilterCheck2 = CreateFrame("CheckButton", "ARLOptionsFilterCheck2", ARLOptionsFilter, "UICheckButtonTemplate")
	ARLOptionsFilterCheck2:ClearAllPoints()
	ARLOptionsFilterCheck2:SetPoint("TOPLEFT", ARLOptionsFilterCheck1, "BOTTOMLEFT", 0, 0)

	if (AckisRecipeList.db.profile.pvp) then

		ARLOptionsFilterCheck2:SetChecked(true)

	end

	ARLOptionsFilterCheck2.Text = ARLOptionsFilterCheck2:CreateFontString("ARLOptionsFilterCheck2Text", "DIALOG")
	ARLOptionsFilterCheck2.Text:SetFontObject("GameFontNormal")
	ARLOptionsFilterCheck2.Text:SetTextColor(1, 1, 1)
	ARLOptionsFilterCheck2.Text:SetWidth(320)
	ARLOptionsFilterCheck2.Text:SetJustifyH("LEFT")
	ARLOptionsFilterCheck2.Text:SetText(L["PVP_TOGGLE"])
	ARLOptionsFilterCheck2.Text:ClearAllPoints()
	ARLOptionsFilterCheck2.Text:SetPoint("LEFT", ARLOptionsFilterCheck2, "RIGHT", 0, 0)

	-- Skill Toggle
	local ARLOptionsFilterCheck3 = CreateFrame("CheckButton", "ARLOptionsFilterCheck3", ARLOptionsFilter, "UICheckButtonTemplate")
	ARLOptionsFilterCheck3:ClearAllPoints()
	ARLOptionsFilterCheck3:SetPoint("TOPLEFT", ARLOptionsFilterCheck2, "BOTTOMLEFT", 0, 0)

	if (AckisRecipeList.db.profile.skill) then

		ARLOptionsFilterCheck3:SetChecked(true)

	end

	ARLOptionsFilterCheck3.Text = ARLOptionsFilterCheck3:CreateFontString("ARLOptionsFilterCheck3Text", "DIALOG")
	ARLOptionsFilterCheck3.Text:SetFontObject("GameFontNormal")
	ARLOptionsFilterCheck3.Text:SetTextColor(1, 1, 1)
	ARLOptionsFilterCheck3.Text:SetWidth(320)
	ARLOptionsFilterCheck3.Text:SetJustifyH("LEFT")
	ARLOptionsFilterCheck3.Text:SetText(L["SKILL_TOGGLE"])
	ARLOptionsFilterCheck3.Text:ClearAllPoints()
	ARLOptionsFilterCheck3.Text:SetPoint("LEFT", ARLOptionsFilterCheck3, "RIGHT", 0, 0)

	-- Factions Toggle
	local ARLOptionsFilterCheck4 = CreateFrame("CheckButton", "ARLOptionsFilterCheck4", ARLOptionsFilter, "UICheckButtonTemplate")
	ARLOptionsFilterCheck4:ClearAllPoints()
	ARLOptionsFilterCheck4:SetPoint("TOPLEFT", ARLOptionsFilterCheck3, "BOTTOMLEFT", 0, 0)

	if (AckisRecipeList.db.profile.faction) then

		ARLOptionsFilterCheck2:SetChecked(true)

	end

	ARLOptionsFilterCheck4.Text = ARLOptionsFilterCheck4:CreateFontString("ARLOptionsFilterCheck4Text", "DIALOG")
	ARLOptionsFilterCheck4.Text:SetFontObject("GameFontNormal")
	ARLOptionsFilterCheck4.Text:SetTextColor(1, 1, 1)
	ARLOptionsFilterCheck4.Text:SetJustifyH("LEFT")
	ARLOptionsFilterCheck4.Text:SetWidth(320)
	ARLOptionsFilterCheck4.Text:SetText(L["FACTION_TOGGLE"])
	ARLOptionsFilterCheck4.Text:ClearAllPoints()
	ARLOptionsFilterCheck4.Text:SetPoint("LEFT", ARLOptionsFilterCheck4, "RIGHT", 0, 0)

	-- Raid Toggle
	local ARLOptionsFilterCheck5 = CreateFrame("CheckButton", "ARLOptionsFilterCheck5", ARLOptionsFilter, "UICheckButtonTemplate")
	ARLOptionsFilterCheck5:ClearAllPoints()
	ARLOptionsFilterCheck5:SetPoint("TOPLEFT", ARLOptionsFilterCheck4, "BOTTOMLEFT", 0, 0)

	if (AckisRecipeList.db.profile.raid) then

		ARLOptionsFilterCheck5:SetChecked(true)

	end

	ARLOptionsFilterCheck5.Text = ARLOptionsFilterCheck5:CreateFontString("ARLOptionsFilterCheck5Text", "DIALOG")
	ARLOptionsFilterCheck5.Text:SetFontObject("GameFontNormal")
	ARLOptionsFilterCheck5.Text:SetTextColor(1, 1, 1)
	ARLOptionsFilterCheck5.Text:SetWidth(320)
	ARLOptionsFilterCheck5.Text:SetJustifyH("LEFT")
	ARLOptionsFilterCheck5.Text:SetText(L["RAID_TOGGLE"])
	ARLOptionsFilterCheck5.Text:ClearAllPoints()
	ARLOptionsFilterCheck5.Text:SetPoint("LEFT", ARLOptionsFilterCheck5, "RIGHT", 0, 0)

	-- Specialities Toggle
	local ARLOptionsFilterCheck6 = CreateFrame("CheckButton", "ARLOptionsFilterCheck6", ARLOptionsFilter, "UICheckButtonTemplate")
	ARLOptionsFilterCheck6:ClearAllPoints()
	ARLOptionsFilterCheck6:SetPoint("TOPLEFT", ARLOptionsFilterCheck5, "BOTTOMLEFT", 0, 0)

	if (AckisRecipeList.db.profile.specialities) then

		ARLOptionsFilterCheck6:SetChecked(true)

	end

	ARLOptionsFilterCheck6.Text = ARLOptionsFilterCheck6:CreateFontString("ARLOptionsFilterCheck6Text", "DIALOG")
	ARLOptionsFilterCheck6.Text:SetFontObject("GameFontNormal")
	ARLOptionsFilterCheck6.Text:SetTextColor(1, 1, 1)
	ARLOptionsFilterCheck6.Text:SetWidth(320)
	ARLOptionsFilterCheck6.Text:SetJustifyH("LEFT")
	ARLOptionsFilterCheck6.Text:SetText(L["SPECIALITY_TOGGLE"])
	ARLOptionsFilterCheck6.Text:ClearAllPoints()
	ARLOptionsFilterCheck6.Text:SetPoint("LEFT", ARLOptionsFilterCheck6, "RIGHT", 0, 0)


	-- Sorting Options frame
	local ARLSortingOptions = CreateFrame("FRAME", "ARLSortingOptions")
	ARLSortingOptions.name = L["SORT_OPTIONS"]
	ARLSortingOptions.parent = ARL.ARLTitle
	InterfaceOptions_AddCategory(ARLSortingOptions)

	local ARLSortingOptionsText1 = ARLSortingOptions:CreateFontString(nil, "ARTWORK")
	ARLSortingOptionsText1:SetFontObject(GameFontNormalLarge)
	ARLSortingOptionsText1:SetJustifyH("LEFT") 
	ARLSortingOptionsText1:SetJustifyV("TOP")
	ARLSortingOptionsText1:ClearAllPoints()
	ARLSortingOptionsText1:SetPoint("TOPLEFT", 16, -16)
	ARLSortingOptionsText1:SetWidth(320)
	ARLSortingOptionsText1:SetText(L["SORT_OPTIONS"])

	local ARLSortingOptionsDropDown = CreateFrame("Frame", "ARLSortingOptionsDropDown", ARLSortingOptions, "UIDropDownMenuTemplate")
	ARLSortingOptionsDropDown:ClearAllPoints()
	ARLSortingOptionsDropDown:SetPoint("TOPLEFT", 16, -50)
	UIDropDownMenu_Initialize(ARLSortingOptionsDropDown, Sorting_DropDown_Initialize)

	 -- Set initial option 
	if (AckisRecipeList.db.profile.sorting == "Name") then 
	 
		UIDropDownMenu_SetSelectedValue(ARLSortingOptionsDropDown, 0)
	 
	elseif (AckisRecipeList.db.profile.sorting == "Skill") then 
	 
		UIDropDownMenu_SetSelectedValue(ARLSortingOptionsDropDown, 1)
 
	elseif (AckisRecipeList.db.profile.sorting == "Unsorted") then 
 
		UIDropDownMenu_SetSelectedValue(ARLSortingOptionsDropDown, 2)
 
	end

	-- Display Options frame
	local ARLOptionsDisplay = CreateFrame("FRAME", "ARLOptionsDisplay")
	ARLOptionsDisplay.name = L["DISPLAY_OPTIONS"]
	ARLOptionsDisplay.parent = ARL.ARLTitle
	InterfaceOptions_AddCategory(ARLOptionsDisplay)

	local ARLOptionsDisplayText1 = ARLOptionsDisplay:CreateFontString(nil, "ARTWORK")
	ARLOptionsDisplayText1:SetFontObject(GameFontNormalLarge)
	ARLOptionsDisplayText1:SetJustifyH("LEFT") 
	ARLOptionsDisplayText1:SetJustifyV("TOP")
	ARLOptionsDisplayText1:ClearAllPoints()
	ARLOptionsDisplayText1:SetPoint("TOPLEFT", 16, -16)
	ARLOptionsDisplayText1:SetWidth(320)
	ARLOptionsDisplayText1:SetText(L["DISPLAY_OPTIONS"])

	-- Use GUI Toggle
	local ARLOptionsDisplayCheck1 = CreateFrame("CheckButton", "ARLOptionsDisplayCheck1", ARLOptionsDisplay, "UICheckButtonTemplate")
	ARLOptionsDisplayCheck1:ClearAllPoints()
	ARLOptionsDisplayCheck1:SetPoint("TOPLEFT", 16, -50)

	if (AckisRecipeList.db.profile.usegui) then

		ARLOptionsDisplayCheck1:SetChecked(true)

	end

	ARLOptionsDisplayCheck1.Text = ARLOptionsDisplayCheck1:CreateFontString("ARLOptionsDisplayCheck1Text", "DIALOG")
	ARLOptionsDisplayCheck1.Text:SetFontObject("GameFontNormal")
	ARLOptionsDisplayCheck1.Text:SetTextColor(1, 1, 1)
	ARLOptionsDisplayCheck1.Text:SetText(L["GUI_TOGGLE"])
	ARLOptionsDisplayCheck1.Text:ClearAllPoints()
	ARLOptionsDisplayCheck1.Text:SetWidth(320)
	ARLOptionsDisplayCheck1.Text:SetJustifyH("LEFT") 
	ARLOptionsDisplayCheck1.Text:SetPoint("LEFT", ARLOptionsDisplayCheck1, "RIGHT", 0, 0)

	-- Move Scan Button Toggle
	local ARLOptionsDisplayCheck2 = CreateFrame("CheckButton", "ARLOptionsDisplayCheck2", ARLOptionsDisplay, "UICheckButtonTemplate")
	ARLOptionsDisplayCheck2:ClearAllPoints()
	ARLOptionsDisplayCheck2:SetPoint("TOPLEFT", ARLOptionsDisplayCheck1, "BOTTOMLEFT", 0, 0)

	if (AckisRecipeList.db.profile.movescanbutton) then

		ARLOptionsDisplayCheck2:SetChecked(true)

	end

	ARLOptionsDisplayCheck2.Text = ARLOptionsDisplayCheck1:CreateFontString("ARLOptionsDisplayCheck1Text", "DIALOG")
	ARLOptionsDisplayCheck2.Text:SetFontObject("GameFontNormal")
	ARLOptionsDisplayCheck2.Text:SetTextColor(1, 1, 1)
	ARLOptionsDisplayCheck2.Text:SetText(L["SCAN_TOGGLE"])
	ARLOptionsDisplayCheck2.Text:ClearAllPoints()
	ARLOptionsDisplayCheck2.Text:SetWidth(320)
	ARLOptionsDisplayCheck2.Text:SetJustifyH("LEFT") 
	ARLOptionsDisplayCheck2.Text:SetPoint("LEFT", ARLOptionsDisplayCheck2, "RIGHT", 0, 0)

end