﻿--[[
****************************************************************************************
AckisRecipeList v0.8
10 April 2008

Author: Ackis on Illidan US Horde
****************************************************************************************

Please see Wowace.com for more information.

****************************************************************************************
]]

--/dump GetMouseFocus()
local Crayon	= LibStub("LibCrayon-3.0")
local BFAC		= LibStub("LibBabble-Faction-3.0"):GetLookupTable()
local L			= AceLibrary("AceLocale-2.2"):new("AckisRecipeList")

AckisRecipeList = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")
ARL = AckisRecipeList

-- Global variables
ARL.RecipeListing = nil
ARL.MissingRecipeListing = nil
ARL.VendorList = nil
ARL.SkillType = nil
ARL.FoundRecipes = nil
ARL.FilteredRecipes = nil
ARL.NumberOfRecipes = nil
ARL.ResetOkayBlizz = nil
ARL.ResetOkayARL = nil
AckisRecipeListFrame = nil

-- Constants
ARL.ARLTitle = "Ackis Recipe List 0.82"
ARL.br = "\n    - "

-- Local variables


-- Command line options for the mod.
-- Allows you to filter which recipes to display based on faction, class, profession speciality, rare raid recipes, and current/max skill level

local command_options = {
    type = "group",
    args =
	{
		display =
		{
			type = "group",
			name = "Display",
			desc = L["DISPLAY_OPTIONS"],
			order = 1,
			args =
			{
				usegui =
				{
					name	= "Use GUI",
					desc	= L["GUI_TOGGLE"],
					type	= "toggle",
					get		= function() return ARL.db.profile.usegui end,
					set		= function() ARL.db.profile.usegui = not ARL.db.profile.usegui end,
					order	= 1,
				},
				movescanbutton =
				{
					name	= "Move Scan Button",
					desc	= L["SCAN_TOGGLE"],
					type	= "toggle",
					get		= function() return ARL.db.profile.movescanbutton end,
					set		= function() ARL.db.profile.movescanbutton = not ARL.db.profile.movescanbutton end,
					order	= 2,
				},
				includefiltered =
				{
					name	= "Include Filtered",
					desc	= L["FILTERCOUNT_TOGGLE"],
					type	= "toggle",
					get		= function() return ARL.db.profile.includefiltered end,
					set		= function() ARL.db.profile.includefiltered = not ARL.db.profile.includefiltered end,
					order	= 3,
				},
			}
		},
        filter =
		{
			type = "group",
			name = "Filter",
			desc = L["FILTER_OPTIONS"],
			order = 2,
			args =
			{
				reputations =
				{
					type = "group",
					name = "Reputations",
					desc = L["REP_OPTIONS"],
					order = 1,
					args =
					{
						Scryer =
						{
							name	= "Scryer",
							desc	= L["SCRYER_TOGGLE"],
							type	= "toggle",
							get		= function() return ARL.db.profile.scryer end,
							set		= function() ARL.db.profile.scryer = not ARL.db.profile.scryer end,
							order	= 1,
						},
						Aldor =
						{
							name	= "Aldor",
							desc	= L["ALDOR_TOGGLE"],
							type	= "toggle",
							get		= function() return ARL.db.profile.aldor end,
							set		= function() ARL.db.profile.aldor = not ARL.db.profile.aldor end,
							order	= 2,
						},
					}
				},
				factions =
				{
					name	= "Faction",
					desc	= L["FACTION_TOGGLE"],
					type	= "toggle",
					get		= function() return ARL.db.profile.faction end,
					set		= function() ARL.db.profile.faction = not ARL.db.profile.faction end,
					order	= 1,
				},
				PVP =
				{
					name	= "PVP",
					desc	= L["PVP_TOGGLE"],
					type	= "toggle",
					get		= function() return ARL.db.profile.pvp end,
					set		= function() ARL.db.profile.pvp = not ARL.db.profile.pvp end,
					order	= 2,
				},
				classes =
				{
                    name      = "Classes",
                    desc      = L["CLASS_TOGGLE"],
                    type      = "toggle",
                    get       = function() return ARL.db.profile.classes end,
                    set       = function() ARL.db.profile.classes = not ARL.db.profile.classes end,
                    order     = 3,
				},
				specialities =
				{
                    name      = "Specialities",
                    desc      = L["SPECIALITY_TOGGLE"],
                    type      = "toggle",
                    get       = function() return ARL.db.profile.specialities end,
                    set       = function() ARL.db.profile.specialities = not ARL.db.profile.specialities end,
                    order     = 4,
				},
				raid =
				{
                    name      = "Raid",
                    desc      = L["RAID_TOGGLE"],
                    type      = "toggle",
                    get       = function() return ARL.db.profile.raid end,
                    set       = function() ARL.db.profile.raid = not ARL.db.profile.raid end,
                    order     = 5,
				},
				skill =
				{
                    name      = "Skill",
                    desc      = L["SKILL_TOGGLE"],
                    type      = "toggle",
                    get       = function() return ARL.db.profile.skill end,
                    set       = function() ARL.db.profile.skill = not ARL.db.profile.skill end,
                    order     = 6,
				}
			}
		},
		sorting =
		{
			name      = "Sort",
			desc      = L["SORT_OPTIONS"],
			type      = "text",
			validate  = {L["SORT_Name"], L["SORT_Skill"]},
			get       = function() return ARL.db.profile.sorting end,
			set       = function(name) ARL:ToggleAllSorting(name) end,
			order     = 3,
		}
	}
}

--[[

	Saved variables functions

]]--

-- Initialize the database and set the default options

ARL:RegisterDB("AckisRecipeListDB", "AckisRecipeListDBPC")

-- Set default options, which are to include everything in the scan
ARL:RegisterDefaults("profile",
	{
    faction = true,
	classes = false,
	pvp = true,
	specialities = false,
	raid = true,
	skill = true,
	usegui = true,
	movescanbutton = false,
	sorting = "Skill",
	aldor = true,
	scryer = true,
	includefiltered = false,
	}
)

-- Toggles the boolean value of the AllFactions variable in the database.

function ARL:ToggleAllSorting(NewValue)

	if (NewValue == L["SORT_Name"]) then

		ARL.db.profile.sorting = "Name"

	elseif (NewValue == L["SORT_Skill"]) then

		ARL.db.profile.sorting = "Skill"

	end

end

--[[

	Reset functions

]]--

-- Empties the RecipeList table

local function ARL_ResetRecipeList()

	if (ARL.RecipeListing ~= nil) then

		local CurrentRecipe = next(ARL.RecipeListing, nil)

		while (CurrentRecipe ~= nil) do

			ARL.RecipeListing[CurrentRecipe]["Level"] = nil
			ARL.RecipeListing[CurrentRecipe]["Acquire"] = nil
			ARL.RecipeListing[CurrentRecipe]["Speciality"] = nil		
			ARL.RecipeListing[CurrentRecipe]["Known"] = nil

			local OldRecipe = CurrentRecipe

			-- Move on to the next entry in the table
			CurrentRecipe = next(ARL.RecipeListing, CurrentRecipe)

			ARL.RecipeListing[OldRecipe] = nil

		end

	end

	ARL.RecipeListing = nil

end

-- Empties the MissingRecipeList table

local function ARL_ResetMissingRecipeList()

	if (ARL.MissingRecipeListing ~= nil) then

		local CurrentRecipe = next(ARL.MissingRecipeListing, nil)

		while (CurrentRecipe ~= nil) do

			ARL.MissingRecipeListing[CurrentRecipe]["Level"] = nil
			ARL.MissingRecipeListing[CurrentRecipe]["Acquire"] = nil
			ARL.MissingRecipeListing[CurrentRecipe]["Speciality"] = nil		
			ARL.MissingRecipeListing[CurrentRecipe]["Known"] = nil

			local OldRecipe = CurrentRecipe

			-- Move on to the next entry in the table
			CurrentRecipe = next(ARL.MissingRecipeListing, CurrentRecipe)

			ARL.MissingRecipeListing[OldRecipe] = nil

		end

	end

	ARL.MissingRecipeListing = nil

end

-- Reset the vendor information table

local function ARL_ResetVendorList()

	if (ARL.VendorList ~= nil) then

		local CurrentVendor = next(ARL.VendorList, nil)

		while (CurrentVendor ~= nil) do
--[[
			ARL.VendorList[CurrentVendor]["Level"] = nil
			ARL.VendorList[CurrentVendor]["Acquire"] = nil
			ARL.VendorList[CurrentVendor]["Speciality"] = nil		
			ARL.VendorList[CurrentVendor]["Known"] = nil
]]--
			local OldVendor = CurrentVendor

			-- Move on to the next entry in the table
			CurrentVendor = next(ARL.VendorList, CurrentVendor)

			ARL.VendorList[OldVendor] = nil

		end

	end

	ARL.VendorList = nil

end

-- Reset all variables

function ARL:ARL_ResetVariables()

	ARL_ResetRecipeList()
	ARL_ResetMissingRecipeList()

	ARL.SkillType = nil
	ARL.FoundRecipes = nil
	ARL.NumberOfRecipes = nil
	ARL.FilteredRecipes = nil

end

-- Initializes the initial recipe array, reseting it completely.

function ARL:InitializeRecipeArray()

	-- Reset namespace to be empty
	ARL.RecipeListing = {}
	ARL.MissingRecipeListing = {}
  
	-- Sets the total number of recipes to 0.
	ARL.NumberOfRecipes = 0

	-- Sets the number of found recipes to 0.
	ARL.FoundRecipes = 0

	-- Sets number of filtered recipes to 0
	ARL.FilteredRecipes = 0

end

--[[

	Initialization functions

]]--

-- When the add-on is enabled, register slash commands, and which events to watch

function ARL:OnEnable()

	-- Add slash commands
	self:RegisterChatCommand(L["LONG_COMMAND"], L["SHORT_COMMAND"], command_options)

	-- Make addon respond to the tradeskill and crafting windows being shown
	self:RegisterEvent("TRADE_SKILL_SHOW")
	self:RegisterEvent("CRAFT_SHOW")

	-- Addon responds to tradeskill and crafting windows being closed.
	self:RegisterEvent("CRAFT_CLOSE")
	self:RegisterEvent("TRADE_SKILL_CLOSE")

	--Create the button now for later use
	ARL_AddScanButton()
	ARL:HideScanButton()

	-- Create the GUI Menu Options
	--ARL:CreateGUIOptions()

	--Allows ARL to be closed with the Escape key
	tinsert(UISpecialFrames, "AckisRecipeListFrame")

end

-- Hides the frame if the mod gets disabled

function ARL:OnDisable()

	ARL:ARL_ResetVariables()
	ARL_ResetVendorList()

	if AckisRecipeListFrame then

		AckisRecipeListFrame:Hide()

	end

	-- Removes ARL entry
	tremove(UISpecialFrames, "AckisRecipeListFrame");

end

-- Watch for the trade skill window to be shown, add all specific trade skills to an array, then scan the trade skill window for all recipes.

function ARL:TRADE_SKILL_SHOW()

	ARL.SkillType = "Trade"
	ARL.ResetOkayBlizz = false
	ARL:ShowScanButton()

end

-- Clean up tables from memory when trade skill window is closed

function ARL:TRADE_SKILL_CLOSE()

	ARL.ResetOkayBlizz = true

	if (ARL.ResetOkayBlizz and ARL.ResetOkayARL) then

		ARL:ARL_ResetVariables()

	end

	ARL:HideScanButton()

end

-- Watch for the craft skill window to be shown, add all specific trade skills to an array, then scan the craft skill window for all recipes.

function ARL:CRAFT_SHOW()

	ARL.SkillType = "Craft"
	ARL.ResetOkayBlizz = false
	ARL:ShowScanButton()

end

-- Clean up tables from memory when craft window is closed

function ARL:CRAFT_CLOSE()

	ARL.ResetOkayBlizz = true

	if (ARL.ResetOkayBlizz and ARL.ResetOkayARL) then

		ARL:ARL_ResetVariables()

	end

	ARL:HideScanButton()

end

--[[

	Tradeskill functions

]]--

-- Adds a specifc recipe to the recipe list array.  Also provides information regarding recipe level, if there is any trade skill recipe speciality, how to aquire the recipe, and if the recipe is known or not.

function ARL:addTradeSkill(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)

	-- Creates a table in the ARL.RecipeListing table storing all information about a recipe
	ARL.RecipeListing[RecipeName] = {}
	ARL.RecipeListing[RecipeName]["Level"] = RecipeLevel
	ARL.RecipeListing[RecipeName]["Acquire"] = RecipeAquire

	if (RecipeSpeciality == nil) then

		ARL.RecipeListing[RecipeName]["Speciality"] = {}

	else

		ARL.RecipeListing[RecipeName]["Speciality"] = RecipeSpeciality

	end

	if (VendorInfo == nil) then

		ARL.RecipeListing[RecipeName]["VendorInfo"] = {}

	else

		ARL.RecipeListing[RecipeName]["VendorInfo"] = VendorInfo

	end

	if (RecipeKnown == nil) then

		ARL.RecipeListing[RecipeName]["Known"] = false

	else

		ARL.RecipeListing[RecipeName]["Known"] = RecipeKnown

	end

	-- Increment the total number of recipes added to the list
	ARL.NumberOfRecipes = ARL.NumberOfRecipes + 1

end

-- Same as previous function but uses spell ID to get recipe name

function ARL:addTradeSkillSpell(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)

	if (GetSpellInfo(RecipeName) ~= nil) then

		ARL:addTradeSkill(GetSpellInfo(RecipeName), RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)

	else

		ARL:addTradeSkill(tostring(RecipeName), RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)
		self:Print("Spell ID: " .. RecipeName .. " is not in your local cache.")

	end

end

-- Same as previous but combines spell rank for beast training

function ARL:addTradeSkillBeast(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)

	local Jimo,Megadopolous = GetSpellInfo(RecipeName)

	if (Jimo ~= nil) then

		local TempHunterSkill = Jimo .. " (" .. Megadopolous .. ")"
		ARL:addTradeSkill(TempHunterSkill, RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)

	else

		ARL:addTradeSkill(tostring(RecipeName), RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)
		self:Print("Spell ID: " .. RecipeName .. " is not in your local cache.")

	end

end

-- Adds vendor information to the vendor list array.

function ARL:addVendorList(VendorID, VendorName, VendorFaction, VendorLoc, VendorCoords)

	ARL.VendorList[VendorID] = {}
	ARL.VendorList[VendorID]["Name"] = VendorName
	ARL.VendorList[VendorID]["Faction"] = VendorFaction
	ARL.VendorList[VendorID]["Location"] = VendorLoc
	ARL.VendorList[VendorID]["Coords"] = VendorCoords

end

-- Modifies recipe array if a recipe is found, setting the Known flag as true.

function ARL:foundTradeSkill(RecipeName)

	ARL.RecipeListing[ RecipeName ][ "Known" ] = true

	-- Increase found count
	ARL.FoundRecipes = ARL.FoundRecipes + 1

end

-- Checks to see if a recipe is known or not.  If the recipe is not in the database, output it to chat.

function ARL:CheckRecipe(RecipeName)

	if (ARL.RecipeListing[ RecipeName ]) then

		-- Update array that recipe was found
		ARL:foundTradeSkill(RecipeName)
	
	else

		-- Notify users in chat that skill is missing from the database.
		ARL:printMissingSkill(RecipeName)

	end

end

-- Check to see if recipe should be displayed or not

function ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)

	-- Display all skill levels
	if (ARL.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then

		if (not ARL.db.profile.skill) then

			ARL.FilteredRecipes = ARL.FilteredRecipes + 1
			return false

		end

	end

	local classcheck = false
	local classoccur = false
	local displaycheck = true

	if (ARL.MissingRecipeListing[RecipeName]["Speciality"] ~= nil) then

		for i, CurrentCheck in pairs(ARL.MissingRecipeListing[RecipeName]["Speciality"]) do

			-- Display hard to obtain raid recipes
			if (not ARL.db.profile.raid) then

				if (CurrentCheck == L["Raid"]) then

					displaycheck = false

				end

			end

			-- Display all faction recipes
			if (not ARL.db.profile.faction) then

				local playerFaction, _ = UnitFactionGroup("player")

				-- Make sure it's Horde or Alliance
				if (CurrentCheck == BFAC["Horde"]) or
				(CurrentCheck == BFAC["Alliance"]) then

					if (CurrentCheck ~= playerFaction) then

						displaycheck = false

					end

				end

			end

			-- Display all class type recipes
			if (not ARL.db.profile.classes) then

				local _, playerClass = UnitClass("player")

				-- Make sure it's a class
				if (CurrentCheck == "WARLOCK") or 
				(CurrentCheck == "WARRIOR") or 
				(CurrentCheck == "HUNTER") or 
				(CurrentCheck == "MAGE") or 
				(CurrentCheck == "PRIEST") or 
				(CurrentCheck == "DRUID") or 
				(CurrentCheck == "PALADIN") or 
				(CurrentCheck == "SHAMAN") or 
				(CurrentCheck == "ROGUE") then

				classoccur = true

					if (CurrentCheck == playerClass) then

						classcheck = true

					end

				end

			end

			-- Display all Scryer recipes
			if (not AckisRecipeList.db.profile.scryer) then

				if (CurrentCheck == BFAC["The Scryers"]) then

					displaycheck = false

				end

			end

			-- Display all Aldor recipes
			if (not AckisRecipeList.db.profile.aldor) then

				if (CurrentCheck == BFAC["The Aldor"]) then

					displaycheck = false

				end

			end

			-- Display all specialities (ie: Primal Mooncloth, Spellcloth, etc.)
			if (not ARL.db.profile.specialities) then

				-- Blacksmithing
				if (CurrentProfession == GetSpellInfo(2018)) then

					if (CurrentCheck == GetSpellInfo(9788)) or -- Armorsmith
						(CurrentCheck == GetSpellInfo(17041)) or -- Master Axesmith
						(CurrentCheck == GetSpellInfo(17040)) or -- Master Hammersmith
						(CurrentCheck == GetSpellInfo(17039)) or -- Master Swordsmith
						(CurrentCheck == GetSpellInfo(9787)) then -- Weaponsmith

							if (CurrentCheck ~= CurrentSpeciality) then

								displaycheck = false

							end

					end

				-- Engineering
				elseif (CurrentProfession == GetSpellInfo(4036)) then

					if (CurrentCheck == GetSpellInfo(20219)) or -- Gnomish Engineering
						(CurrentCheck == GetSpellInfo(20222)) then -- Goblin Engineering

							if (CurrentCheck ~= CurrentSpeciality) then

								displaycheck = false

							end

					end

				-- Leatherworking
				elseif (CurrentProfession == GetSpellInfo(2108)) then

					if (CurrentCheck == GetSpellInfo(10657)) or -- Dragonscale
						(CurrentCheck == GetSpellInfo(10659)) or -- Elemental
						(CurrentCheck == GetSpellInfo(10661)) then -- Tribal

							if (CurrentCheck ~= CurrentSpeciality) then

								displaycheck = false

							end

					end

				-- Tailoring
				elseif (CurrentProfession == GetSpellInfo(3908)) then

					if (CurrentCheck == GetSpellInfo(26797)) or -- Spellfire
						(CurrentCheck == GetSpellInfo(26801)) or -- Shadoweave
						(CurrentCheck == GetSpellInfo(26798)) then -- Primal Mooncloth

							if (CurrentCheck ~= CurrentSpeciality) then

								displaycheck = false

							end

					end

				end

			end

		end

	end

	if (displaycheck == true) then

		if (classoccur == true) then

			if (classcheck == false) then

				ARL.FilteredRecipes = ARL.FilteredRecipes + 1

			end

			return classcheck

		else

			return true

		end

	else

		ARL.FilteredRecipes = ARL.FilteredRecipes + 1
		return false

	end

end

-- Returns the number of recipes missing

function ARL:GetNumMissingRecipes()

	return ARL.NumberOfRecipes - ARL.FoundRecipes

end

-- Scans the first 24 entries in the spellbook to find which profession speciality someone is (assumption is that it will be within the first 24 because of the general tab)

function ARL:GetTradeSpeciality(CurrentProfession)

local index = 1

	while true do

		local spellName, _ = GetSpellName(index, BOOKTYPE_SPELL)

		if (not spellName) or (index == 25) then

			return ""

		end

		-- Alchemy
		if (CurrentProfession == GetSpellInfo(2259)) then

			if (spellName == GetSpellInfo(28674)) or
				(spellName == GetSpellInfo(28678)) or
				(spellName == GetSpellInfo(28676)) then

				return spellName

			end

		-- Blacksmithing
		elseif (CurrentProfession == GetSpellInfo(2018)) then

			if (spellName == GetSpellInfo(9787)) or
				(spellName == GetSpellInfo(9788)) or
				(spellName == GetSpellInfo(17039)) or
				(spellName == GetSpellInfo(17040)) or
				(spellName == GetSpellInfo(17041)) then

				return spellName

			end

		-- Engineering
		elseif (CurrentProfession == GetSpellInfo(4036)) then

		if (spellName == GetSpellInfo(20219)) or (spellName == GetSpellInfo(20222)) then

				return spellName

			end

		-- Leatherworking
		elseif (CurrentProfession == GetSpellInfo(2108)) then

			if (spellName == GetSpellInfo(10657)) or
				(spellName == GetSpellInfo(10659)) or
				(spellName == GetSpellInfo(10661)) then

				return spellName

			end

		-- Tailoring
		elseif (CurrentProfession == GetSpellInfo(3980)) then

			if (spellName == GetSpellInfo(26797)) or -- Spellfire
				(spellName == GetSpellInfo(26798)) or -- Primal Mooncloth
				(spellName == GetSpellInfo(26801)) then -- Shadoweave

				return spellName

			end

		end

		index = index + 1

	end

end

--[[

	Output functions

]]--

-- Prints out to chat a message stating that a current recipe is missing from the internal database.

function ARL:printMissingSkill(RecipeName)

	self:Print(Crayon:Red(RecipeName) .. Crayon:White(L["MissingFromDB"]))

end

-- Prints out to chat the recipe and where it can be found.

function ARL:PrintRecipeInfo(RecipeName)

	if (ARL.MissingRecipeListing[RecipeName]["Acquire"] ~= nil) then

		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["MissingRecipePrefix"]) .. Crayon:Green(RecipeName .. " - [" .. ARL.MissingRecipeListing[ RecipeName ][ "Level" ] .. "]") .. ARL.br .. ARL.MissingRecipeListing[ RecipeName ][ "Acquire" ])

	else

		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["MissingRecipePrefix"]) .. Crayon:Green(RecipeName .. " - [" .. ARL.MissingRecipeListing[ RecipeName ][ "Level" ] .. "]"))

	end

end

-- Combines Vendor name, location, faction into a single string

function ARL:ARL_AddVendor(VendorList, LSupply)

	local VendorInfo

	if (LSupply == false) then

		VendorInfo = L["Vendor"]
	
	else

		VendorInfo = L["LimitedSupply"]

	end

	local playerFaction, _ = UnitFactionGroup("player")

	for i, CurrentCheck in pairs(VendorList) do

		local CurrentVendor = ARL.br .. ARL.VendorList[CurrentCheck]["Name"] .. " - " .. ARL.VendorList[CurrentCheck]["Location"] .. ": " .. ARL.VendorList[CurrentCheck]["Coords"]

		if (ARL.VendorList[CurrentCheck]["Faction"] == BFAC["Alliance"]) then

			if (AckisRecipeList.db.profile.faction or playerFaction == BFAC["Alliance"]) then

				VendorInfo = VendorInfo .. Crayon:Cyan(CurrentVendor)

			end

		elseif (ARL.VendorList[CurrentCheck]["Faction"] == BFAC["Horde"]) then

			if (AckisRecipeList.db.profile.faction or playerFaction == BFAC["Horde"]) then

				VendorInfo = VendorInfo .. Crayon:Red(CurrentVendor)

			end

		elseif (ARL.VendorList[CurrentCheck]["Faction"] == BFAC["Neutral"]) then

			VendorInfo = VendorInfo .. Crayon:Gold(CurrentVendor)

		else

			VendorInfo = VendorInfo .. CurrentVendor

		end

	end

	return VendorInfo

end

-- Combines a rep level and faction into a single string

function ARL:ARL_AddReputation1(RepLevel, Faction)

	return format("%s: %s", RepLevel, Faction)

end

-- Combines a rep level and two factions into a single string

function ARL:ARL_AddReputation2(RepLevel, Faction1, Faction2)

	return format("(A) %s: %s%s(H) %s: %s", RepLevel, Faction1, ARL.br, RepLevel, Faction2)

end

-- Identifies that a scan is occuring in chat

function ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)

	if (CurrentSpeciality == "") then

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Copper(ARL.ARLTitle))
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["InitiateScan"]:format(CurrentProfession, CurrentProfessionLevel)))

	else

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["InitiateScanSpecial"]:format(CurrentProfession, CurrentSpeciality, CurrentProfessionLevel)))
	
	end

end

-- Displays a summary of known recipes, total recipes and percentages.

function ARL:PrintRecipeListSummary()

	DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["RecipeListSummary"]:format(ARL.FoundRecipes, ARL.NumberOfRecipes, math.floor(ARL.FoundRecipes / ARL.NumberOfRecipes * 100), ARL:GetNumMissingRecipes())))

end

-- Determines which recipes are known and which are not known, printing them out to the chat frame.

function ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedList, CurrentProfession, CurrentSpeciality)

	-- Parse the ARL.MissingRecipeListing, printing out the entries
	if (ARL.MissingRecipeListing ~= nil) then

		-- No sorting at all
		if (SortedList == nil) then

			local RecipeName = next(ARL.MissingRecipeListing, nil)

			while (RecipeName ~= nil) do

				if (ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

					ARL:PrintRecipeInfo(RecipeName)

				end

				-- Move on to the next entry in the table
				RecipeName = next(ARL.MissingRecipeListing, RecipeName)
	
			end

		else

			for i, RecipeName in ipairs(SortedList) do

				if (ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

					ARL:PrintRecipeInfo(RecipeName)

				end

			end

		end

	end

	ARL:PrintRecipeListSummary()

end

--[[

	Sorting Functions

]]--

-- Returns true if a Recipe1 has a lower skill level than Recipe2

local function ARL_SortMissingSkill(Recipe1, Recipe2)

	return ARL.MissingRecipeListing[ Recipe1 ][ "Level" ] < ARL.MissingRecipeListing[ Recipe2 ][ "Level" ]

end

-- Returns true if a Recipe1 come before Recipe2 in the alphabet

local function ARL_SortMissingName(Recipe1, Recipe2)

	return Recipe1 < Recipe2

end

-- Sorts the ARL.MissingRecipeListing with the given sorting function

function ARL:SortMissingRecipes(SortFunction)

	local TempRecipeSort = {}

	-- Get all the indexes of the ARL.MissingRecipeListing
	for n in pairs(ARL.MissingRecipeListing) do

		table.insert(TempRecipeSort, n)

	end

	-- Sort the indexes according to the function
	table.sort(TempRecipeSort, SortFunction)

	return TempRecipeSort

end 

--[[
	Recipe Array Functions

]]--

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeTradeRecipes(CurrentProfession)

	if (CurrentProfession == GetSpellInfo(2259)) then

		-- Add all alchemy recipes to the table
		ARL:ARL_InitAlchemy()
		
	elseif (CurrentProfession == GetSpellInfo(2018)) then
		
		-- Add all blacksmithing recipes to the table
		ARL:ARL_InitBlackSmith()

	elseif (CurrentProfession == GetSpellInfo(2550)) then

		-- Add all cooking recipes to the table
		ARL:ARL_InitCooking()

	elseif (CurrentProfession == GetSpellInfo(4036)) then
		
		-- Add all engineering recipes to the table
		ARL:ARL_InitEngineering()
	
	elseif (CurrentProfession == GetSpellInfo(3273)) then

		-- Add all first aid recipes to the table
		ARL:ARL_InitFirstAid()

	elseif (CurrentProfession == GetSpellInfo(2108)) then

		-- Add all leatherworking recipes to the table		
		ARL:ARL_InitLeatherWorking()

	elseif (CurrentProfession == GetSpellInfo(2842)) then

		-- Add all rogue poisons recipes to the table
		ARL:ARL_InitRoguePoison()

	elseif (CurrentProfession == GetSpellInfo(2575)) then

		-- Add all smelting recipes to the table
		ARL:ARL_InitSmelting()

	elseif (CurrentProfession == GetSpellInfo(3908)) then

		-- Add all tailoring recipes to the table
		ARL:ARL_InitTailoring()

	-- Burning Crusade Professions
	elseif (CurrentProfession == GetSpellInfo(25229)) then

		-- Add all jewelcrafting recipes to the table
		ARL:ARL_InitJewelcrafting()

	else

		self:Print(L["UnknownTradeSkill"]:format(CurrentProfession))
		
	end

end

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeCraftRecipes(CurrentProfession)

	local CurrentProfessionLevel

	if (CurrentProfession == GetSpellInfo(7411)) then

		-- Get the current level of the craft.
		CurrentProfessionLevel = _G["CraftRankFrame"]:GetValue() --Better way to do this?

		-- Add all enchanting recipes to the table
		ARL:ARL_InitEnchanting()

	elseif (CurrentProfession == GetSpellInfo(5149)) then

		-- Player level = profession level for beast training
		CurrentProfessionLevel = UnitLevel("player")

		-- Add all beast training recipes to the table
		ARL:ARL_InitBeastTraining()

	else

		CurrentProfessionLevel = 0
		self:Print(L["UnknownTradeSkill"]:format(CurrentProfession))

	end

	return CurrentProfessionLevel

end

--[[

	Scanning functions

]]--

-- Scans your recipe book for Trade Skill Recipes

function ARL:ScanTradeSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumTradeSkills() do

		local skillName, RecipeHeader, _, _ = GetTradeSkillInfo(i)

		-- Ignore all trade skill headers
		if (RecipeHeader ~= "header") then

			ARL:CheckRecipe(skillName)

		-- If it is a header then expand it so scanning can continue
		else

			ExpandTradeSkillSubClass(i)
		
		end

	end
	
end

-- Scans the ARL.RecipeListing adding all missing recipes to the ARL.MissingRecipeListing

function ARL:ScanMissingRecipes()

	-- Parse the recipe listing table, adding entries to the ARL.MissingRecipeListing table
	if (ARL.RecipeListing ~= nil) then

		local RecipeName = next(ARL.RecipeListing, nil)

			while (RecipeName ~= nil) do

				-- If the recipe is not known then print out the info
				if (ARL.RecipeListing[RecipeName]["Known"] == false) then

					ARL.MissingRecipeListing[RecipeName] = {}
					ARL.MissingRecipeListing[RecipeName]["Level"] = ARL.RecipeListing[RecipeName]["Level"]
					ARL.MissingRecipeListing[RecipeName]["Acquire"] = ARL.RecipeListing[RecipeName]["Acquire"]
					ARL.MissingRecipeListing[RecipeName]["Speciality"] = ARL.RecipeListing[RecipeName]["Speciality"]

				end

				-- Move on to the next entry in the table
				RecipeName = next(ARL.RecipeListing, RecipeName)
	
			end

	end

	-- Done with RecipeList now, so I can empty the table to free up memory now
	ARL_ResetRecipeList()

end

-- Scans your recipe book for Craft Skill Recipes (enchanting is handled differently than other trade skills)

function ARL:ScanCraftSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		local skillName, _, RecipeHeader, _, isExpanded, _, _ = GetCraftInfo(i)

		-- Ignore all trade skill headers
		if (RecipeHeader ~= "header") then

			ARL:CheckRecipe(skillName)

		-- If it is a header then expand it so scanning can continue
		else

			ExpandCraftSkillLine(i)

		end

	end

end

-- Scans your recipe book for beast training skills

function ARL:ScanBeastTraining(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, skillRank, _, _, _, _, _ = GetCraftInfo(i) -- Don't need a lot of this information, what to do with it?

		local FullSkillName = skillName .. " (" .. skillRank .. ")"

		ARL:CheckRecipe(FullSkillName)

	end

end

-- Main logic for add-on, will call all sub-functions

function ARL:AckisRecipeList_Command()

	local CurrentProfession, CurrentProfessionLevel, CurrentSpeciality, SortedRecipeIndex

	-- Initializes the vendor list
	if (ARL.VendorList == nil) then

		ARL.VendorList = {}
		ARL:ARL_InitVendor()

	end

	ARL:InitializeRecipeArray()

	if (ARL.SkillType == nil) then

		self:Print(L["OpenTradeSkillWindow"])

	-- Trade type skills
	elseif (ARL.SkillType == "Trade") then

		-- Get the name of the current trade skill opened, along with the current level of the skill. 
		CurrentProfession, CurrentProfessionLevel, _ = GetTradeSkillLine()

		CurrentSpeciality = ARL:GetTradeSpeciality(CurrentProfession)

		ARL_InitializeTradeRecipes(CurrentProfession)

		if (CurrentProfession == GetSpellInfo(2842)) then

			-- Player level = profession level for rogue poisons
			CurrentProfessionLevel = UnitLevel("player")

		end

		ARL:ScanTradeSkills(CurrentProfession)

		ARL:ScanMissingRecipes()

		if (ARL.db.profile.sorting == "Skill") then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingSkill)

		elseif (ARL.db.profile.sorting == "Name") then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingName)

		end

		if (AckisRecipeList.db.profile.usegui) then

			ARL:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

		else

			ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)
			ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex, CurrentProfession, CurrentSpeciality)

		end

	-- Craft type skills
	elseif (ARL.SkillType == "Craft") then

		-- Get the name of the current craft.
		CurrentProfession = GetCraftName()

		CurrentProfessionLevel = ARL_InitializeCraftRecipes(CurrentProfession)

		CurrentSpeciality = ARL:GetTradeSpeciality(CurrentProfession)

		if (CurrentProfession == GetSpellInfo(7411)) then

			-- Scan for missing enchanting recipes
			ARL:ScanCraftSkills(CurrentProfession)

		elseif (CurrentProfession == GetSpellInfo(5149)) then

			-- Scan for missing beast training
			ARL:ScanBeastTraining(CurrentProfession)

		end

		ARL:ScanMissingRecipes()

		if (ARL.db.profile.sorting == "Skill") then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingSkill)

		elseif (ARL.db.profile.sorting == "Name") then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingName)

		end

		if (AckisRecipeList.db.profile.usegui) then

			ARL:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

		else

			ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)
			ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex, CurrentProfession, CurrentSpeciality)

		end

	end

end

